<?php
declare(strict_types=1);

namespace Catequil\Plugin\Container;

use Catequil\Plugin\Configuration;
use Laminas\ServiceManager\Factory\FactoryInterface;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\ContainerInterface;
use Psr\Container\NotFoundExceptionInterface;

use function constant;
use function defined;

/**
 * Class ConfigurationFactory
 *
 * @package Catequil\Plugin\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-plugin
 */
final class ConfigurationFactory implements FactoryInterface
{
    private const CONFIG_CONSTANTS = [
        'CATEQUIL_BASE_URI' => 'base_uri',
        'CATEQUIL_USERNAME' => 'username',
        'CATEQUIL_PASSWORD' => 'password',
        'CATEQUIL_WEBSHOP' => 'webshop',
    ];

    /**
     * @param ContainerInterface $container
     * @param $requestedName
     * @param array|null $options
     *
     * @return Configuration
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, ?array $options = null): Configuration
    {
        $config = $container->has('config') ? ($container->get('config')['catequil'] ?? []) : [];

        foreach (self::CONFIG_CONSTANTS as $constant => $key) {
            if (defined($constant)) {
                $config[$key] = constant($constant);
            }
        }

        return new Configuration(
            $config
        );
    }
}
