<?php
declare(strict_types=1);

namespace Catequil\Plugin\Container;

use Catequil\Plugin\Configuration;
use GuzzleHttp\Client;
use Laminas\ServiceManager\Factory\FactoryInterface;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\ContainerInterface;
use Psr\Container\NotFoundExceptionInterface;

/**
 * Class HttpClientFactory
 *
 * @package Catequil\Plugin\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-plugin
 */
final class HttpClientFactory implements FactoryInterface
{
    /**
     * @param ContainerInterface $container
     * @param $requestedName
     * @param array|null $options
     *
     * @return Client
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, ?array $options = null): Client
    {
        /** @var Configuration $config */
        $config = $container->get(Configuration::class);

        return new Client([
            'base_uri' => $config->getBaseUri(),
            'auth' => [
                $config->getUsername(),
                $config->getPassword(),
            ],
        ]);
    }
}
