<?php
declare(strict_types=1);

namespace Catequil\Plugin\Gateway;

use GuzzleHttp\Exception\GuzzleException;
use JsonException;
use WC_Order;
use WC_Order_Item_Product;

use function array_map;
use function json_decode;

/**
 * Class PackageGateway
 *
 * @package Catequil\Plugin\Gateway
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-plugin
 */
final class PackageGateway extends AbstractGateway
{
    public const PACKAGE_META_KEY = '_catequilPackageId';

    /**
     * @param WC_Order $order
     *
     * @return array
     * @throws GuzzleException
     * @throws JsonException
     */
    public function createForOrder(WC_Order $order): array
    {
        $response = $this->http->post('packing/package', [
            'json' => [
                'orderId' => $order->get_id(),
                'webshop' => $this->config->getWebshop(),
                'priority' => $this->config->getPriority($order->get_shipping_method()),
                'items' => array_map(
                    fn (WC_Order_Item_Product $item) => [
                        'sku' => $item->get_product()->get_sku(),
                        'quantity' => $item->get_quantity(),
                    ],
                    $order->get_items(),
                ),
            ],
        ]);

        $contents = $response->getBody()->getContents();
        return json_decode($contents, true, 512, JSON_THROW_ON_ERROR);
    }
}
