<?php
declare(strict_types=1);

namespace Catequil\Plugin\Handler;

use Catequil\Plugin\Gateway\PackageGateway;
use GuzzleHttp\Exception\GuzzleException;
use Throwable;
use WC_Order;

use function add_action;
use function get_post_meta;
use function in_array;
use function update_post_meta;

/**
 * Class OrderHandler
 *
 * @package Catequil\Plugin\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-plugin
 */
final class OrderHandler
{
    private const CREATE_PACKAGE_STATUS = [
        'pakiranje',
        'cekanje-uplate',
    ];

    private PackageGateway $packages;

    /**
     * @param PackageGateway $packages
     */
    public function __construct(PackageGateway $packages)
    {
        $this->packages = $packages;

        add_action('woocommerce_order_status_changed', [$this, 'create_package'], 10, 4);
    }

    /**
     * @param int $orderId
     * @param string $statusFrom
     * @param string $statusTo
     * @param WC_Order $order
     *
     * @return void
     * @noinspection PhpUnusedParameterInspection
     */
    public function create_package(int $orderId, string $statusFrom, string $statusTo, WC_Order $order): void
    {
        $packageId = get_post_meta($orderId, PackageGateway::PACKAGE_META_KEY, true);

        if ($packageId || !in_array($statusTo, self::CREATE_PACKAGE_STATUS)) {
            return;
        }

        try {
            $package = $this->packages->createForOrder($order);

            if (isset($package['id'])) {
                update_post_meta($orderId, PackageGateway::PACKAGE_META_KEY, $package['id']);

                $order->add_order_note(
                    "Stvoren je novi paket u Catequilu, id: {$package['id']}."
                );
            }
        } catch (Throwable $e) {
            $order->add_order_note(
                "Došlo je do greške prilikom stvaranja novog paketa u Catequilu: {$e->getMessage()}."
            );
        }
    }
}
